// Author: Philipp Moers <soziflip funny character gmail dot com>

var

// DOM objects
wrapper         = document.getElementById('wrapper'),
canvas          = document.getElementById('drawingarea'),
canvascontext   = canvas.getContext('2d'),
pensizepicker   = document.getElementById('pensizepicker'),
colorpicker     = document.getElementById('colorpicker'),

// is the user drawing right now?
drawmode = false,
// what pen should we use baby?
color, pensize, useCircles;



////////////////////
// EVENT HANDLERS //
////////////////////

canvas.addEventListener('mousedown', enableDrawmode, false);
canvas.addEventListener('mouseup', disableDrawmode, false);
canvas.addEventListener('mousemove', draw, false);

colorpicker.addEventListener('change', updateColor, false);
pensizepicker.addEventListener('change', updatePensize, false);
useCirclesCheckbox.addEventListener('change', updateUseCircles, false);



////////////////
// INITIALIZE //
////////////////

updateColor();
updatePensize();
updateUseCircles();



//////////////////////////
// FUNCTION DEFINITIONS //
//////////////////////////


// button functions
function clearImage() {
    if (confirm("You are sure you want to delete the current image?"))
        canvascontext.clearRect(0, 0, canvas.width, canvas.height);
}
function saveImage() {
    // alert("This functionality is not implemented yet. Sorry!");
   var image = canvas.toDataURL("image/png")
               .replace("image/png", "image/octet-stream");
   window.location.href = image;
   alert("The file you just received is an ordinary png file. Just rename it!");
}

// event handlers
function enableDrawmode() {
    drawmode = true;
}
function disableDrawmode() {
    drawmode = false;
}
function updateColor() {
    color = document.getElementById('colorpicker').value;
    console.log('updated color to ' + color);
}
function updatePensize() {
    pensize = document.getElementById('pensizepicker').value;
    console.log('updated pensize to ' + pensize);
}
function updateUseCircles() {
    useCircles = document.getElementById('useCirclesCheckbox').checked;
    console.log('updated useCircles to ' + useCircles);
}

// get relative canvas mouse position
function getMousePos(canvas, event) {
    var x = event.clientX - canvas.offsetLeft,
        y = event.clientY - canvas.offsetTop;
    return {x: x, y: y};
}

// draw something, if mouse is down and moving
function draw(event) {
    // only draw when in draw mode (mouse down)
    if (drawmode) {
        var mousePos = getMousePos(canvas, event);
        // console.log("drawing at " + JSON.stringify(mousePos));
        useCircles ?
            drawCirc(mousePos, pensize/2) :
            drawRect(mousePos, pensize, pensize);
    }
}
// draw a rectangle with given parameters
function drawRect(origin, width, height) {
    canvascontext.fillStyle = color;
    canvascontext.fillRect(origin.x - width/2,
                           origin.y - height/2,
                           width, height);
}
// draw a circle with given parameters
function drawCirc(origin, radius) {
    canvascontext.beginPath();
    canvascontext.arc(origin.x, origin.y, radius, 0, 2 * Math.PI, false);
    canvascontext.closePath();
    canvascontext.fillStyle = color;
    canvascontext.fill();
}

